*================== PROGRAM: PSI17_PROV_OBSERVED.SAS =======================================;
*
*  TITLE: PROGRAM PSI17_PROV_OBSERVED.SAS CALCULATES OBSERVED PROVIDER LEVEL RATES 
*         FOR AHRQ PATIENT SAFETY INDICATOR - PSI 17: BIRTH TRAUMA RATE - INJURY TO NEONATE
*
*  DESCRIPTION:
*         USES PROC SUMMARY TO CALCULATE POPULATION AND OBSERVED RATES FOR
*         PATIENT SAFETY INDICATOR 17 ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, BWHTCAT, AGEDCAT, PAGECAT, SEXCAT, 
*         PAYCAT, RACECAT.
*         THIS INDICATOR IS ALSO INCLUDED IN THE PEDIATRIC  
*         QUALITY INDICATOR MODULE.
*
*         AHRQ QI VERSION 6.0.2 ICD-09-CM
*         VERSION DATE AUGUST 2017
*==========================================================================================;
*PATHNAME specifies the location of the PSI_17 folder which includes the
          Programs, Macros, and SASdata subfolders;
filename CONTROL "c:\pathname\PSI_17\Programs\PSI17_ALL_CONTROL.SAS";  *<===USER MUST modify;
%include CONTROL;

 title2 'PROGRAM: PSI17_PROV_OBSERVED';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE OBSERVED PROVIDER RATES';

 * ------------------------------------------------------------------ ;
 * --- PROVIDER LEVEL SUMMARY USING PSI17_ALL_MEASURES.SAS OUTPUT --- ;
 * --- VARIABLES TPPDxx AND PPPDxx ARE CREATED IN MEASURES AND    --- ;
 * --- ARE USED TO CREATE THE OPPDxx VARIABLES.                   --- ;
 * ------------------------------------------------------------------ ;
 
 * ---------------------------------------------------------------- ;
 * --- PATIENT SAFETY INDICATOR (PSI) NAMING CONVENTION:        --- ;
 * --- THE FIRST LETTER IDENTIFIES THE INDICATOR AS ONE OF      --- ;
 * --- THE FOLLOWING:                                    
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
                (O) OBSERVED RATES
 * --- THE SECOND LETTER IDENTIFIES THE TYPE OF INDICATOR WITH  --- ;
 * --- 'P' FOR PROVIDER LEVEL. THE NEXT TWO CHARACTERS ARE      --- ;
 * --- 'PS'. THE LAST TWO DIGITS ARE 17 FOR INDICATOR PSI 17.   --- ;
 * ---------------------------------------------------------------- ;

data TEMP0;
  set OUTMSR.&OUTFILE_MEAS.;
run;

proc Summary data=TEMP0;
  class  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
  var    TPPS17;
  output out=&OUTFILE_PROVOBS.
         sum (TPPS17)=
         N(TPPS17)=PPPS17
         mean(TPPS17)=OPPS17;
run;

proc Sort data=&OUTFILE_PROVOBS.;
  by HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
run;

data OUTPOBS.&OUTFILE_PROVOBS.;
  set &OUTFILE_PROVOBS. (where=(_TYPE_ &TYPELVLP));
  label
     TPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Numerator)'
     PPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Population)'
     OPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Observed)'
     _TYPE_ = 'STRATIFICATION LEVEL'
  ;
  drop _FREQ_ ;
run;

* -------------------------------------------------------------- ;
* --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
* -------------------------------------------------------------- ;

proc Contents data=OUTPOBS.&OUTFILE_PROVOBS. position;
run;

  ***----- TO PRINT VARIABLE LABELS COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max sum mean nolabels;
   var TPPS17;
   title  'SUMMARY PROVIDER-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=64';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max sum nolabels;
   var PPPS17 ;
   title  'SUMMARY OF PATIENT SAFETY PROVIDER-LEVEL INDICATOR 17 OVERALL DENOMINATOR (SUM) WHEN _TYPE_=64';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max mean nolabels;
   var OPPS17;
   title  'SUMMARY OF PATIENT SAFETY PROVIDER-LEVEL OBSERVED INDICATOR 17 AVERAGE RATES(MEAN) WHEN _TYPE_=64';
run; quit;

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE ----------------------- ;
 * -------------------------------------------------------------- ;

%MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 proc Print data=OUTPOBS.&OUTFILE_PROVOBS. label SPLIT='*';

 var    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD.  ;
 label HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       ;
 format BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. 13.0;
 title4 "Indicator &PD.: &TEXT";

 run;

 %MEND PRT;

 %PRT(PS17,Birth Trauma Rate - Injury to Neonate);

 %END;

%MEND PRT2;

%PRT2;

* -------------------------------------------------------------- ;
* --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
* --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
* -------------------------------------------------------------- ;

%MACRO TEXTP1;

%IF &TEXTPOBS. = 1  %THEN %DO;

 data _NULL_;
   set OUTPOBS.&OUTFILE_PROVOBS.;
   file PDPOBS lrecl=2000;
   if _N_=1 then do;
   put "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," "Sex"  "," "Payer" "," "Race" "," "Type" ","
       "TPPS17" "," 
       "PPPS17" "," 
       "OPPS17" 
   ;
   end;
   put HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
   (TPPS17) (7.0 ",")
    ","
   (PPPS17) (13.2 ",")
   ","
   (OPPS17) (12.10 ",")
   ;
 run;

%END;

%MEND TEXTP1;

%TEXTP1;
